/* 
 * Copyright (c) 2008 Jesper Karlsson & David Gustafsson
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#include <gtk/gtk.h>
#include <libxfce4ui/libxfce4ui.h>

#include "xfbib-input-dialog.h"

struct _XfbibInputDialog
{
	XfceTitledDialog parent;
	GtkWidget *string_key_label;
	GtkWidget *text_label;
	GtkWidget *string_key_entry;
	GtkWidget *text_entry;
};

typedef struct _XfbibInputDialogClass
{
	XfceTitledDialogClass parent;
} XfbibInputDialogClass;

static void xfbib_input_dialog_class_init(XfbibInputDialogClass *klass);

static void xfbib_input_dialog_init(XfbibInputDialog *instance);
static void xfbib_input_dialog_finalize(GObject *obj);

static GObjectClass *xfbib_input_dialog_parent_class = NULL;

GType
xfbib_input_dialog_get_type (void)
{
	static GType type = 0;
	if (type == 0) {
		static const GTypeInfo info = {
			sizeof (XfbibInputDialogClass),
			NULL,   /* base_init */
			NULL,   /* base_finalize */
			(GClassInitFunc) xfbib_input_dialog_class_init,   /* class_init */
			NULL,   /* class_finalize */
			NULL,   /* class_data */
			sizeof (XfbibInputDialog),
			0,      /* n_preallocs */
			(GInstanceInitFunc) xfbib_input_dialog_init    /* instance_init */
		};
		type = g_type_register_static (XFCE_TYPE_TITLED_DIALOG, "XfbibInputDialog", &info, 0);
	}
	return type;
}

	
static void
xfbib_input_dialog_class_init(XfbibInputDialogClass *klass)
{
	GObjectClass *object_class = (GObjectClass *)klass;
	
	xfbib_input_dialog_parent_class = g_type_class_peek_parent (klass); 

	object_class->finalize = xfbib_input_dialog_finalize;
}

static void
xfbib_input_dialog_init(XfbibInputDialog *instance)
{
	GtkWidget *table;
	
	table = gtk_table_new(2,2,FALSE);

	gtk_table_set_row_spacings(GTK_TABLE(table), 6);
	gtk_table_set_col_spacings(GTK_TABLE(table), 12);
	gtk_container_set_border_width(GTK_CONTAINER (table), 6);

	instance->string_key_label = gtk_label_new(_("String key:"));
	instance->text_label = gtk_label_new(_("Text:"));

	instance->string_key_entry = gtk_combo_box_entry_new();
	instance->text_entry = gtk_entry_new();

	gtk_table_attach(GTK_TABLE(table), instance->string_key_label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
	gtk_table_attach(GTK_TABLE(table), instance->text_label, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 0, 0);

	gtk_table_attach_defaults(GTK_TABLE(table), instance->string_key_entry, 0, 1, 0, 1);
	gtk_table_attach_defaults(GTK_TABLE(table), instance->text_entry, 1, 2, 0, 1);

	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (instance)->vbox), table, FALSE, TRUE, 6);

	/* Add OK and cancel button */
	gtk_dialog_add_button (GTK_DIALOG (instance), GTK_STOCK_OK, GTK_RESPONSE_OK);
	gtk_dialog_add_button (GTK_DIALOG (instance), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
	
	gtk_dialog_set_default_response (GTK_DIALOG (instance), GTK_RESPONSE_CANCEL);
	gtk_window_set_icon_name(GTK_WINDOW(instance), "xfbib");
	gtk_widget_show_all(GTK_WIDGET(instance));
}

static void
xfbib_input_dialog_finalize(GObject *obj)
{
	G_OBJECT_CLASS(xfbib_input_dialog_parent_class)->finalize(obj);
}

GtkWidget *
xfbib_input_dialog_new(gchar *title, const gchar *label)
{
	XfbibInputDialog *input_dialog;
	//gchar *lbl;
	input_dialog = g_object_new(XFBIB_TYPE_INPUT_DIALOG,
			"destroy-with-parent", ((GTK_DIALOG_MODAL & GTK_DIALOG_DESTROY_WITH_PARENT) != 0),
			"has-separator", ((GTK_DIALOG_MODAL & GTK_DIALOG_NO_SEPARATOR) == 0),
			"modal", ((GTK_DIALOG_MODAL & GTK_DIALOG_MODAL) != 0),
			"title", title,
			NULL);
	
	//lbl = g_strdup_printf("%s:", label);
	//gtk_label_set_text(GTK_LABEL(input_dialog->label), lbl);
	//g_free(lbl);
	return GTK_WIDGET(input_dialog);
}

const gchar *xfbib_input_dialog_get_string_key(XfbibInputDialog *instance)
{
	return gtk_combo_box_get_active_text(GTK_COMBO_BOX(instance->string_key_entry));
}

const gchar *xfbib_input_dialog_get_text(XfbibInputDialog *instance)
{
	return gtk_entry_get_text(GTK_ENTRY(instance->text_entry));
}

