#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#include <gtk/gtk.h>

#include "xfbib-state.h"

struct _XfbibState
{
	GObject parent;
	XfbibBibtex *elements;
	gchar *filename;
	GtkWidget *window;
};

typedef struct _XfbibStateClass
{
	GObjectClass parent;
} XfbibStateClass;

static void xfbib_state_class_init(XfbibStateClass *klass);

static void xfbib_state_init(XfbibState *instance);
static void xfbib_state_finalize(GObject *obj);

static XfbibState *xfbib_state_singleton = NULL;

G_DEFINE_TYPE(XfbibState, xfbib_state, G_TYPE_OBJECT)

static void
xfbib_state_class_init(XfbibStateClass *klass)
{
	GObjectClass *object_class = (GObjectClass *)klass;
	object_class->finalize = xfbib_state_finalize;
}

static void
xfbib_state_init(XfbibState *instance)
{
	instance->elements = NULL;
	instance->filename = NULL;
	instance->window = NULL;
}

static void
xfbib_state_finalize(GObject *obj)
{
	G_OBJECT_CLASS(xfbib_state_parent_class)->finalize(obj);
}

XfbibState *
xfbib_state_new()
{
	XfbibState *state;
	
	if (xfbib_state_singleton == NULL) {
		state = g_object_new(XFBIB_TYPE_STATE, NULL);
		xfbib_state_singleton = g_object_ref(G_OBJECT(state));
	} else {
		state = g_object_ref(G_OBJECT(xfbib_state_singleton));
	}

	return state;
}

void xfbib_state_set_filename(XfbibState *state, gchar *filename)
{
	g_return_if_fail(XFBIB_IS_STATE(state));
	g_free(state->filename);
	state->filename = g_strdup(filename);
}

gchar *xfbib_state_get_filename(XfbibState *state)
{
	g_return_val_if_fail(XFBIB_IS_STATE(state), NULL);
	return state->filename;
}

void xfbib_state_set_bibtex_elements(XfbibState *state, XfbibBibtex *elements)
{
	g_return_if_fail(XFBIB_IS_STATE(state));
	state->elements = elements;
}

XfbibBibtex *xfbib_state_get_bibtex_elements(XfbibState *state)
{
	g_return_val_if_fail(XFBIB_IS_STATE(state), NULL);
	return state->elements;
}

void xfbib_state_set_window(XfbibState *state, GtkWidget *window)
{
	g_return_if_fail(XFBIB_IS_STATE(state));
	state->window = window;
}

GtkWidget *xfbib_state_get_window(XfbibState *state)
{
	g_return_val_if_fail(XFBIB_IS_STATE(state), NULL);
	return state->window;
}
